@@ -10,6 +10,8 @@
 #' of the point locations where the \code{z} variable was observed.
 #' @param lon Vector of numeric values containing the x coordinate (longitude) 
 #' of the point locations where the \code{z} variable was observed.
+#' @param lags Numerical vector; upper boundaries of lag-distance classes. See
+#' argument \code{boundaries} of \code{\link[gstat]{variogram}} for more info.
 #' @param cutoff Integer value defining the spatial separation distance up to 
 #' which point pairs are included in semivariance estimates. Defaults to the 
 #' length of the diagonal of the box spanning the data divided by three.
@@ -39,14 +41,10 @@
 #' 
 #' @author Alessandro Samuel-Rosa \email{alessandrosamuelrosa@@gmail.com}
 #' 
-#' @section TODO:
-#' The next version should include an option to pass data using an object of 
-#' class \code{"SpatialPointsDataFrame"}.
-#' 
 #' @seealso \code{\link[gstat]{variogram}}, \code{\link[pedometrics]{plotHD}},
 #' \code{\link[sp]{bubble}}, \code{\link[sp]{spplot}}.
+#' @importFrom graphics plot
 #' @export
-#' @import gstat sp
 #' @examples
 #' # require(gstat)
 #' # data(meuse)
@@ -55,9 +53,18 @@
 #' @keywords dplot
 #' 
 # FUNCTION #####################################################################
-#
 plotESDA <- 
-  function (z, lat, lon, cutoff, width = c(cutoff / 20)) {
+  function (z, lat, lon, lags, cutoff, width = c(cutoff / 20)) {
+    
+    # Check if suggested packages are installed
+    pkg <- c("gstat", "sp")
+    id <- !sapply(pkg, requireNamespace, quietly = TRUE)
+    if (any(id)) {
+      pkg <- paste(pkg[which(id)], collapse = " ")
+      stop(paste("Package(s) needed for this function to work but not",
+                 "installed: ", pkg, sep = ""), call. = FALSE)
+    }
+    
     if (missing(z)) {
       stop("<z> is a mandatory argument")
     }
@@ -80,15 +87,28 @@ plotESDA <-
       stop("<z>, <lat> and <lon> must have the same length")
     }
     db <- data.frame(lon = lon, lat = lat, z = z)
-    coordinates(db) <- ~ lon + lat
-    if (missing(cutoff)) {
-      cutoff <- max(variogram(z ~ 1, loc = db)$dist) 
+    sp::coordinates(db) <- ~ lon + lat
+    
+    # Estimate the cutoff
+    cutoff <- max(gstat::variogram(z ~ 1, loc = db)$dist)
+    
+    # Bubble plot
+    v1 <- sp::bubble(db, zcol = "z", fill = FALSE, main = "", maxsize = 1)
+    
+    # Variogram map
+    v2 <- gstat::variogram(z ~ 1, loc = db, map = TRUE, cutoff = cutoff, 
+                           width = width)
+    v2 <- sp::spplot(v2$map[2], col.regions = sp::bpy.colors(64))
+    
+    # Sample variogram
+    if (missing(lags)) {
+      v3 <- gstat::variogram(z ~ 1, loc = db, cutoff = cutoff, width = width)
+    } else {
+      v3 <- gstat::variogram(z ~ 1, loc = db, boundaries = lags)
     }
-    v1 <- bubble(db, zcol = "z", fill = FALSE, main = "", maxsize = 1)
-    v2 <- variogram(z ~ 1, loc = db, map = TRUE, cutoff = cutoff, width = width)
-    v2 <- spplot(v2$map[2], col.regions = bpy.colors(64))
-    v3 <- variogram(z ~ 1, loc = db, cutoff = cutoff, width = width)
     v3 <- plot(v3, cex = 0.5, type = "b", pch = 20, asp = 1)
+    
+    # Histogram
     v4 <- plotHD(z, HD = "over", stats = FALSE, asp = 1, xlab = "z",
                  col = c("skyblue", "red"))
     print(v4, split = c(1, 1, 2, 2), more = TRUE)
@@ -96,4 +116,4 @@ plotESDA <-
     print(v1, split = c(2, 1, 2, 2), more = TRUE)
     print(v2, split = c(2, 2, 2, 2), more = FALSE)
   }
-# End!
\ No newline at end of file
+# End!
